---
title: "Overview"
---

Flower is a Python package with a single purpose: to make human-friendly
documentation from machine-friendly metadata. It takes metadata
contained in a [Data Package's](https://datapackage.org)
`datapackage.json` file and converts them into an output that is
designed for humans and can be shared as a website or plain text files.

## Why use Flower?

The overall aim of the [Seedcase Project](https://seedcase-project.org)
is to build tools that make data more
[FAIR](https://www.go-fair.org/fair-principles/), better documented, and
more discoverable. To support this goal, Flower improves the display of
metadata, which helps with discoverability and ease of sharing. This is
an important part in making data FAIR, considering that one of the
biggest barriers to (re-)using data, particularly research data, is the
lack of well-documented metadata. For example, having information on how
any given variable was collected, what the units are, and why the data
was collected in the first place makes it much easier to effectively use
data in a reliable and accurate way.

Flower is especially useful considering that there are few tools
available that allow you to take metadata that describe a dataset or set
of related datasets and make them into a format that is easy to share
and easy to read (for humans). Even within the
[Frictionless Data](https://frictionlessdata.io) ecosystem, which is the
organisation responsible for initially starting and developing the Data
Package specification, there are no tools for doing this. The closest
match is a graphical user interface called
[Open Data Editor](https://opendataeditor.okfn.org) that can display the
metadata, however it isn't very flexible, isn't easy to customise, and
is mainly designed around editing metadata.

## Learning more

This website contains documentation on Flower's design, how to use it,
and details about the interface.

- [How-to guide](/docs/guide/index.qmd): The guide section provides a
  step-by-step introduction to Flower, including installing, using the
  command-line interface, setting configurations, and creating
  customised styles.
- [Reference](/docs/reference/index.qmd): The reference section contains
  detailed information about Flower's API, specifically the
  documentation of individual Python classes and functions.
- [Design](/docs/design/index.qmd): The design section describes the
  architecture and interface of Flower, the requirements, use-cases, and
  [C4 model](https://c4model.com/) diagrams.

## Contributors

{{< include /docs/includes/_contributors.qmd >}}
